pub enum IValidatorConfigErrors {
Unauthorized(Unauthorized),
ValidatorAlreadyExists(ValidatorAlreadyExists),
ValidatorNotFound(ValidatorNotFound),
InvalidPublicKey(InvalidPublicKey),
NotHostPort(NotHostPort),
NotIpPort(NotIpPort),
}Expand description
Container for all the IValidatorConfig custom errors.
Variants
ValidatorAlreadyExists(ValidatorAlreadyExists)
ValidatorNotFound(ValidatorNotFound)
InvalidPublicKey(InvalidPublicKey)
NotHostPort(NotHostPort)
NotIpPort(NotIpPort)
Implementations
Sourceimpl IValidatorConfigErrors
impl IValidatorConfigErrors
Sourcepub const SELECTORS: &'static [[u8; 4]]
pub const SELECTORS: &'static [[u8; 4]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
Sourcepub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
Sourcepub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.
Sourceimpl ValidatorConfigError
impl ValidatorConfigError
Creates an error for unauthorized access.
Sourcepub const fn validator_already_exists() -> Self
pub const fn validator_already_exists() -> Self
Creates an error when validator already exists.
Sourcepub const fn validator_not_found() -> Self
pub const fn validator_not_found() -> Self
Creates an error when validator is not found.
Sourcepub const fn invalid_public_key() -> Self
pub const fn invalid_public_key() -> Self
Creates an error when public key is invalid (zero).
pub fn not_host_port(field: String, input: String, backtrace: String) -> Self
pub fn not_ip_port(field: String, input: String, backtrace: String) -> Self