pub struct changeValidatorStatusByIndexCall {
pub index: u64,
pub active: bool,
}Expand description
Change validator active status by index (owner only) - T1+
@param index The validator index in the validators array
@param active Whether the validator should be active
@dev Added in T1 to prevent front-running attacks where a validator changes its address
Function with signature changeValidatorStatusByIndex(uint64,bool) and selector 0x5aa3d0e1.
function changeValidatorStatusByIndex(uint64 index, bool active) external;Fields
index: u64active: boolTrait Implementations
Sourceimpl Clone for changeValidatorStatusByIndexCall
impl Clone for changeValidatorStatusByIndexCall
Sourcefn clone(&self) -> changeValidatorStatusByIndexCall
fn clone(&self) -> changeValidatorStatusByIndexCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for changeValidatorStatusByIndexCall
impl<'de> Deserialize<'de> for changeValidatorStatusByIndexCall
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonAbiExt for changeValidatorStatusByIndexCall
impl JsonAbiExt for changeValidatorStatusByIndexCall
Sourceimpl PartialEq for changeValidatorStatusByIndexCall
impl PartialEq for changeValidatorStatusByIndexCall
Sourcefn eq(&self, other: &changeValidatorStatusByIndexCall) -> bool
fn eq(&self, other: &changeValidatorStatusByIndexCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl SolCall for changeValidatorStatusByIndexCall
impl SolCall for changeValidatorStatusByIndexCall
Sourceconst SIGNATURE: &'static str = "changeValidatorStatusByIndex(uint64,bool)"
const SIGNATURE: &'static str = "changeValidatorStatusByIndex(uint64,bool)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>, Bool)
type Parameters<'a> = (Uint<64>, Bool)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<changeValidatorStatusByIndexCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<changeValidatorStatusByIndexCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding [TokenSeq] type.
Sourcetype Return = changeValidatorStatusByIndexReturn
type Return = changeValidatorStatusByIndexReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<changeValidatorStatusByIndexCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<changeValidatorStatusByIndexCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding [TokenSeq] type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
fn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
fn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
fn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
fn abi_encode(&self) -> Vec<u8> ⓘ
fn abi_encode(&self) -> Vec<u8> ⓘ
ABI encode the call to the given buffer with its selector.
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ
ABI encode the call’s return value.
impl Eq for changeValidatorStatusByIndexCall
impl StructuralPartialEq for changeValidatorStatusByIndexCall